@@ -2,13 +2,13 @@
 
 # Build zipfiles for ATK on Win32
 
-ZIP=/tmp/atk-0.7-`date +%Y%m%d`.zip
-DEVZIP=/tmp/atk-dev-0.7-`date +%Y%m%d`.zip
-cd /usr
+ZIP=/tmp/atk-0.11-`date +%Y%m%d`.zip
+DEVZIP=/tmp/atk-dev-0.11-`date +%Y%m%d`.zip
+cd /opt/gnome-2.0
 
 rm $ZIP
 zip -r $ZIP -@ <<EOF
-lib/libatk-7.dll
+lib/libatk-11.dll
 EOF
 
 rm $DEVZIP
